@@ -82,6 +82,7 @@ from sklearn.metrics import (accuracy_score,
                              fbeta_score,
                              mean_squared_error,
                              mean_absolute_error,
+                             matthews_corrcoef,
                              hamming_loss)
 from sklearn.metrics.pairwise import cosine_distances, cosine_similarity, euclidean_distances
 from sklearn.pipeline import Pipeline, FeatureUnion, make_pipeline
@@ -103,6 +104,7 @@ from torch.utils.data import Dataset, TensorDataset, DataLoader
 from torch.utils.tensorboard import SummaryWriter
 import nltk
 import spacy
+import requests
 from textblob import TextBlob
 import ipywidgets as widgets
 from pprint import pprint
@@ -110,6 +112,7 @@ from typing import List, Dict, Tuple, Union, Optional
 from loguru import logger
 from fns.notebook import *
 from sklearn.inspection import permutation_importance
+from tqdm.auto import tqdm
 """.strip().splitlines()
 
 for import_line in imports:
